==> qtjambi-quick-5.15.4-sources.jar: io/qt/quick/QSGTextureProvider.java <==
package io.qt.quick;


/**
 * <p>Encapsulates texture based entities in QML</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qsgtextureprovider.html">QSGTextureProvider</a></p>
 */
public abstract class QSGTextureProvider extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QSGTextureProvider.class);
    
    @io.qt.NativeAccess
    private static final class ConcreteWrapper extends QSGTextureProvider {
        
        @io.qt.NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @io.qt.QtUninvokable
        public io.qt.quick.QSGTexture texture(){
            return texture_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native io.qt.quick.QSGTexture texture_native_constfct(long __this__nativeId);
        
    }
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qsgtextureprovider.html#textureChanged">QSGTextureProvider::textureChanged()</a></p>
     */
    public final Signal0 textureChanged = new Signal0();
    
    public QSGTextureProvider(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QSGTextureProvider instance);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qsgtextureprovider.html#texture">QSGTextureProvider::texture()const</a></p>
     */
    @io.qt.QtUninvokable
    public abstract io.qt.quick.QSGTexture texture();
    
    @io.qt.QtUninvokable
    private native io.qt.quick.QSGTexture texture_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QSGTextureProvider(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QSGTextureProvider(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QSGTextureProvider instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-quick-6.2.10-sources.jar: io/qt/quick/QSGTextureProvider.java <==
package io.qt.quick;


/**
 * <p>Encapsulates texture based entities in QML</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qsgtextureprovider.html">QSGTextureProvider</a></p>
 */
public abstract class QSGTextureProvider extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QSGTextureProvider.class);
    
    @io.qt.NativeAccess
    private static final class ConcreteWrapper extends QSGTextureProvider {
        
        @io.qt.NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @io.qt.QtUninvokable
        public io.qt.quick.QSGTexture texture(){
            return texture_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native io.qt.quick.QSGTexture texture_native_constfct(long __this__nativeId);
        
    }
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qsgtextureprovider.html#textureChanged">QSGTextureProvider::textureChanged()</a></p>
     */
    public final Signal0 textureChanged = new Signal0();
    
    public QSGTextureProvider(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QSGTextureProvider instance);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qsgtextureprovider.html#texture">QSGTextureProvider::texture()const</a></p>
     */
    @io.qt.QtUninvokable
    public abstract io.qt.quick.QSGTexture texture();
    
    @io.qt.QtUninvokable
    private native io.qt.quick.QSGTexture texture_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QSGTextureProvider(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QSGTextureProvider(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QSGTextureProvider instance, QDeclarativeConstructor constructor);
    
}
